@@ -16,13 +16,15 @@
 import sys
 import json
 
+from flexneuart.io import open_with_default_enc
+
 
 def get_num_datapoint_annotated(json_dataset):
     return sum([len(json_dataset[i]) for i in list(json_dataset.keys())])
 
 
 def load_json(filename):
-    with open(filename, "r") as f:
+    with open_with_default_enc(filename, "r") as f:
         return json.load(f)
 
 if __name__ == "__main__":
