@@ -18,32 +18,43 @@ import sys
 import argparse
 import torch
 
+from flexneuart.config import DEFAULT_VAL_BATCH_SIZE
+
+from flexneuart.models.train.amp import get_amp_processors
 from flexneuart.models.utils import add_model_init_basic_args
 from flexneuart.models.base import ModelSerializer
 
+from flexneuart.text_proc import handle_case
+
 from flexneuart.featextr_server.python_generated.protocol.ExternalScorer import TextEntryRaw
 from flexneuart.featextr_server.base import BaseQueryHandler, start_query_server
 
-import flexneuart.models.train.data as data
 
-from flexneuart.models.train.data import DOC_TOK_FIELD, DOC_MASK_FIELD, \
-    QUERY_TOK_FIELD, QUERY_MASK_FIELD, QUERY_ID_FIELD, DOC_ID_FIELD
-
-DEFAULT_BATCH_SIZE = 32
+from flexneuart.models.train.batch_obj import BatchObject
+from flexneuart.models.train.batching import BatchingValidationGroupByQuery
 
+# Candidate score weights cannot be used as of right now unfortunately
 class RankQueryHandler(BaseQueryHandler):
     # Exclusive==True means single-threaded processing, which seems to be necessary here (there were hang ups otherwise)
     def __init__(self,
                     model_list,
+                    keep_case,
                     batch_size, device_name,
                     max_query_len, max_doc_len,
+                    #cand_score_weight,
                     exclusive,
+                    amp,
                     debug_print=False):
         super().__init__(exclusive=exclusive)
 
         self.debug_print = debug_print
         self.batch_size = batch_size
 
+        self.amp = amp
+        self.do_lower_case = not keep_case
+
+        #self.cand_score_weight = cand_score_weight
+
         self.max_query_len = max_query_len
         self.max_doc_len = max_doc_len
         self.device_name = device_name
@@ -55,6 +66,8 @@ class RankQueryHandler(BaseQueryHandler):
             # need to be in the eval mode
             model.eval()
 
+    def handle_case(self, text: str):
+        return handle_case(self.do_lower_case, text)
 
     def compute_scores_from_parsed_override(self, query, docs):
         # Sending words array with subsequent concatenation is quite inefficient in Python (very-very inefficient)
@@ -70,18 +83,20 @@ class RankQueryHandler(BaseQueryHandler):
     def compute_scores_from_raw_override(self, query, docs):
         print('Processing query:', query.id, query.text, '# of docs: ', len(docs))
 
-        query_data = {query.id: query.text}
+        query_data = {query.id: self.handle_case(query.text)}
         # Run maps queries to arrays of document IDs see iter_valid_records (train_model.py)
         run = {query.id: {e.id : 0 for e in docs}}
 
         doc_data = {}
         for e in docs:
-            doc_data[e.id] = e.text
+            doc_data[e.id] = self.handle_case(e.text)
 
         model_qty = len(self.model_list)
         # Initialize the return dictionary: for each document ID, a zero-element array of the size # of models.
         sample_ret = {e.id : [0.] * model_qty for e in docs}
 
+        auto_cast_class, _ = get_amp_processors(self.amp)
+
         if doc_data:
 
             # based on the code from run_model function (train_model.py)
@@ -89,21 +104,24 @@ class RankQueryHandler(BaseQueryHandler):
             # must disable gradient computation to greatly reduce memory requirements and speed up things
             with torch.no_grad():
                 for model_id, model in enumerate(self.model_list):
-                    for records in data.iter_valid_records(model, self.device_name, data_set, run,
-                                                           self.batch_size,
-                                                           self.max_query_len, self.max_doc_len):
+                    iter_val = BatchingValidationGroupByQuery(batch_size=self.batch_size,
+                                                              dataset=data_set,
+                                                              model=model,
+                                                              max_query_len=self.max_query_len,
+                                                              max_doc_len=self.max_doc_len,
+                                                              run=run)
 
-                        scores = model(records[QUERY_TOK_FIELD],
-                                       records[QUERY_MASK_FIELD],
-                                       records[DOC_TOK_FIELD],
-                                       records[DOC_MASK_FIELD])
-
-
-                        # tolist() works much faster compared to extracting scores
-                        # one by one using .item()
+                    for batch in iter_val():
+                        batch: BatchObject = batch
+                        batch.to(self.device_name)
+                        model_scores = model(*batch.features)
+                        assert len(model_scores) == len(batch)
+                        #scores = model_scores + batch.cand_scores * self.cand_score_weight
+                        scores = model_scores
+                        # tolist() works much faster compared to extracting scores one by one using .item()
                         scores = scores.tolist()
 
-                        for qid, did, score in zip(records[QUERY_ID_FIELD], records[DOC_ID_FIELD], scores):
+                        for qid, did, score in zip(batch.query_ids, batch.doc_ids, scores):
                             if self.debug_print:
                                 print('model id:', model_id, 'score & doc. id:', score, did, doc_data[did])
 
@@ -116,7 +134,6 @@ class RankQueryHandler(BaseQueryHandler):
         return sample_ret
 
 
-
 if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='A ranking server.')
 
@@ -126,7 +143,7 @@ if __name__ == '__main__':
                         help='Provide debug output')
 
     parser.add_argument('--batch_size', metavar='batch size',
-                        default=DEFAULT_BATCH_SIZE, type=int,
+                        default=DEFAULT_VAL_BATCH_SIZE, type=int,
                         help='batch size')
 
     parser.add_argument('--port', metavar='server port',
@@ -137,6 +154,13 @@ if __name__ == '__main__':
                         default='127.0.0.1', type=str,
                         help='server host addr to bind the port')
 
+    parser.add_argument('--keep_case', action='store_true',
+                        help='no lower-casing')
+
+    # parser.add_argument('--cand_score_weight', metavar='candidate provider score weight',
+    #                     type=float, default=0.0,
+    #                     help='a weight of the candidate generator score used to combine it with the model score.')
+
 
     args = parser.parse_args()
 
@@ -152,8 +176,7 @@ if __name__ == '__main__':
     all_max_doc_len = None
 
     if args.init_model_list is not None:
-        for model_file in args.init_model_list:
-            fname = model_file.name
+        for fname in args.init_model_list:
 
             print('Loading model from:', fname)
 
@@ -178,14 +201,17 @@ if __name__ == '__main__':
         sys.exit(1)
 
 
-    print(f'Max query/document lengths: {all_max_query_len}/{all_max_doc_len}')
+    print(f'Max query/document lengths: {all_max_query_len}/{all_max_doc_len}, keep case? {args.keep_case}')
 
 
     multi_threaded = False  # if we set to True, we can often run out of CUDA memory.
     start_query_server(args.host, args.port, multi_threaded, RankQueryHandler(model_list=model_list,
+                                                                              amp=args.amp,
+                                                                              keep_case=args.keep_case,
                                                                               batch_size=args.batch_size,
                                                                               debug_print=args.debug_print,
                                                                               device_name=args.device_name,
                                                                               max_query_len=all_max_query_len,
                                                                               max_doc_len=all_max_doc_len,
+                                                                              #cand_score_weight=args.cand_score_weight,
                                                                               exclusive=not multi_threaded))
